=============================================
API documentation for interacting with Galaxy
=============================================

GalaxyInstance
--------------

.. autoclass:: bioblend.galaxy.GalaxyInstance

    .. automethod:: bioblend.galaxy.GalaxyInstance.__init__

-----

.. _libraries-api:

Datasets
--------

.. automodule:: bioblend.galaxy.datasets

-----

Datatypes
---------

.. automodule:: bioblend.galaxy.datatypes

-----

Folders
-------

.. automodule:: bioblend.galaxy.folders

-----

Forms
-----

.. automodule:: bioblend.galaxy.forms

-----

FTP files
---------

.. automodule:: bioblend.galaxy.ftpfiles

-----

Genomes
-------

.. automodule:: bioblend.galaxy.genomes

Groups
------

.. automodule:: bioblend.galaxy.groups

-----

Histories
---------

.. automodule:: bioblend.galaxy.histories

-----

Jobs
----

.. automodule:: bioblend.galaxy.jobs

-----

Libraries
---------

.. automodule:: bioblend.galaxy.libraries

-----

Quotas
------

.. automodule:: bioblend.galaxy.quotas

-----

Roles
-----

.. automodule:: bioblend.galaxy.roles

-----

Tools
-----

.. automodule:: bioblend.galaxy.tools

-----

Tool data tables
----------------

.. automodule:: bioblend.galaxy.tool_data

-----

ToolShed
--------

.. automodule:: bioblend.galaxy.toolshed

-----

Users
-----

.. automodule:: bioblend.galaxy.users

-----

Visual
--------

.. automodule:: bioblend.galaxy.visual

-----

.. _workflows-api:

Workflows
---------

.. automodule:: bioblend.galaxy.workflows


.. _objects-api:

==========================
Object-oriented Galaxy API
==========================

.. autoclass:: bioblend.galaxy.objects.galaxy_instance.GalaxyInstance

Client
------

.. automodule:: bioblend.galaxy.objects.client

Wrappers
--------

.. automodule:: bioblend.galaxy.objects.wrappers
